==> iconify_field-1.0.0-rc4.tar.gz: iconify_field/modules/iconify_field_ckeditor/js/ckeditor5_plugins/IconifyFieldPlugin/src/insert_iconify_field_command.ts <==
import type { Writer } from '@ckeditor/ckeditor5-engine'
import { Command } from 'ckeditor5/src/core'

interface IconifyFieldConfig {
  defaultCollection?: string
  collections?: string
}

export default class InsertIconifyFieldCommand extends Command {
  override execute() {
    const { model } = this.editor

    const config = this.editor.config.get('iconifyField') as IconifyFieldConfig

    const query = new URLSearchParams({
      default_collection: config.defaultCollection ?? '',
      collections: config.collections ?? '',
    })

    // @ts-expect-error Drupal is a global variable
    const modal = Drupal.ajax({
      url: `/admin/iconify_field/menu-icons/picker?${query}`,
      dialogType: 'modal',
      dialog: {
        height: 600,
        width: 800,
      },
    })

    modal.execute()

    document.body.addEventListener('iconify-field-pick-icon', (event: any) => {
      const closeBtn = document.body.querySelector('.ui-dialog-titlebar-close')
      if (closeBtn)
        (closeBtn as HTMLElement).click()

      const icon = event.detail.text

      model.change((writer) => {
        model.insertObject(
          createIconifyField(writer, icon),
          null,
          null,
          {
            setSelection: 'on',
          },
        )
      })
    })
  }

  override refresh() {
    const { model } = this.editor
    const { selection } = model.document

    const position = selection.getFirstPosition()

    if (!position)
      return

    const allowedIn = model.schema.findAllowedParent(
      position,
      'iconifyField',
    )

    this.isEnabled = allowedIn !== null
  }
}

function createIconifyField(writer: Writer, icon?: string) {
  const iconifyField = writer.createElement('iconifyField', {
    'data-icon': icon,
  })

  return iconifyField
}

==> iconify_field-1.1.1.tar.gz: iconify_field/modules/iconify_field_ckeditor/js/ckeditor5_plugins/IconifyFieldPlugin/src/insert_iconify_field_command.ts <==
import type { Writer } from '@ckeditor/ckeditor5-engine'
import { Command } from 'ckeditor5/src/core'

interface IconifyFieldConfig {
  defaultCollection?: string
  collections?: string
}

interface InsertIconifyFieldCommandOptions {
  icon: string
  attributes: {
    [key: string]: any
  }
}

export default class InsertIconifyFieldCommand extends Command {
  override execute(options?: InsertIconifyFieldCommandOptions) {
    const { model } = this.editor

    if (options?.icon) {
      model.change((writer) => {
        model.insertObject(
          this._createIconifyField(writer, options.icon, options.attributes),
          null,
          null,
          {
            setSelection: 'on',
          },
        )
      })

      return
    }

    const config = this.editor.config.get('iconifyField') as IconifyFieldConfig

    const query = new URLSearchParams({
      default_collection: config.defaultCollection ?? '',
      collections: config.collections ?? '',
    })

    const modal = Drupal.ajax({
      url: `/admin/iconify_field/menu-icons/picker?${query}`,
      dialogType: 'modal',
      dialog: {
        height: 600,
        width: 800,
      },
    })

    modal.execute()

    document.body.addEventListener('iconify-field-pick-icon', (event: any) => {
      const closeBtn = document.body.querySelector('.ui-dialog-titlebar-close')
      if (closeBtn)
        (closeBtn as HTMLElement).click()

      const icon = event.detail.text

      model.change((writer) => {
        model.insertObject(
          this._createIconifyField(writer, icon, {
            'class': 'iconify-field',
            'aria-hidden': 'true',
          }),
          null,
          null,
          {
            setSelection: 'on',
          },
        )
      })
    })
  }

  override refresh() {
    const { model } = this.editor
    const { selection } = model.document

    const position = selection.getFirstPosition()

    if (!position)
      return

    const allowedIn = model.schema.findAllowedParent(
      position,
      'iconifyField',
    )

    this.isEnabled = allowedIn !== null
  }

  private _createIconifyField(
    writer: Writer,
    icon?: string,
    attributes?: { [key: string]: any },
  ) {
    const iconifyField = writer.createElement('iconifyField', {
      'data-icon': icon,
      ...attributes,
    })

    return iconifyField
  }
}
